@@ -1,8 +1,8 @@
 """
-Module: 'sys' on micropython-v1.18-esp8266
+Module: 'sys' on micropython-v1.19.1-esp8266
 """
-# MCU: {'ver': 'v1.18', 'port': 'esp8266', 'arch': 'xtensa', 'sysname': 'esp8266', 'release': '1.18', 'name': 'micropython', 'mpy': 9733, 'version': '1.18', 'machine': 'ESP module with ESP8266', 'build': '', 'nodename': 'esp8266', 'platform': 'esp8266', 'family': 'micropython'}
-# Stubber: 1.5.4
+# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'esp8266', 'port': 'esp8266', 'machine': 'ESP module (1M) with ESP8266', 'release': '1.19.1', 'nodename': 'esp8266', 'name': 'micropython', 'family': 'micropython', 'sysname': 'esp8266', 'version': '1.19.1'}
+# Stubber: 1.5.6
 from typing import Any
 
 argv = []  # type: list
@@ -27,5 +27,5 @@ def print_exception(*args, **kwargs) -> Any:
 stderr: Any  ## <class 'FileIO'> = <io.FileIO 2>
 stdin: Any  ## <class 'FileIO'> = <io.FileIO 0>
 stdout: Any  ## <class 'FileIO'> = <io.FileIO 1>
-version = "3.4.0"  # type: str
+version = "3.4.0; MicroPython v1.19.1 on 2022-06-18"  # type: str
 version_info = ()  # type: tuple
